#!/bin/bash
#
# Startup script for Hmedia ClockClient
#
#
# description: Hmedia ClockClient presents iNEWS Showtiming Clocks on Desktop
# 

# Setup initial variables
# =======================
# LIBS: an array of all needed jar files inside the $CLOCKSERVER_HOME/lib directory
LOGFILE="/var/log/ClockClient"
LIBS=(
	commons-beanutils.jar
	commons-collections-3.1.jar
	commons-configuration-1.3.jar
	commons-lang-2.2.jar
	commons-logging-1.0.4.jar
)

# Functions
running_instances() {
	ps -ef | grep "clockclient.jar" | grep -v "grep" | wc -l | sed -e 's/^[\t ]*//'
}

# Set the directory where the ClockClient software is sitting in:
if [ "$(readlink $0)" != "" ]
then
        CLOCKCLIENT_HOME="$(dirname $(readlink $0))"
else
        CLOCKCLIENT_HOME="$(dirname $0 | pwd)"
fi

# Check for existence of needed config files
CLOCKCLIENT_CONFIG="$CLOCKCLIENT_HOME/clientconf.xml"
test -r "$CLOCKCLIENT_CONFIG" || { echo "$CLOCKCLIENT_CONFIG not existing." >> $LOGFILE;
	if [ "$1" = "stop" ]; then exit 0;
	else exit 6; fi; }

# Set environment variables
export CLOCKCLIENT_HOME
test $(echo "$PATH" | grep "$CLOCKCLIENT_HOME") || PATH=$PATH:"$CLOCKCLIENT_HOME"
export PATH

# Check for missing binaries (stale symlinks should not happen)
test -x /usr/bin/java || { echo "Java not properly installed (Hmedia ClockClient assumes JRE executable link in /usr/bin directory)." >> $LOGFILE; 
	if [ "$1" = "stop" ]; then exit 0;
	else exit 5; fi; }
test -f "$CLOCKCLIENT_HOME/clockclient.jar" || { echo "$CLOCKCLIENT_HOME/clockclient.jar not installed." >> $LOGFILE; 
	if [ "$1" = "stop" ]; then exit 0;
	else exit 5; fi; }

# Check for libs and create classpath variable
LOCALCLASSPATH="$CLOCKCLIENT_HOME/clockclient.jar"
for LIBFILE in ${LIBS[@]}
do
	test -f "$CLOCKCLIENT_HOME/lib/$LIBFILE" || { echo "$CLOCKCLIENT_HOME/lib/$LIBFILE not installed." >> $LOGFILE; 
		if [ "$1" = "stop" ]; then exit 0;
		else exit 5; fi; }
	LOCALCLASSPATH="$LOCALCLASSPATH:$CLOCKCLIENT_HOME/lib/$LIBFILE"
done

# Check for suitable Java version
if ! /usr/bin/java -version 2>&1 | head -1 | grep "version" > /dev/null 2>&1
then
	echo "Not able to check Java version." >> $LOGFILE
	exit 1
fi
if /usr/bin/java -version 2>&1 | head -1 | grep "1.[0-5]." > /dev/null 2>&1
then
	echo "Invalid Java Runtime Environment. Need version 1.6.x or higher" >> $LOGFILE
	exit 5
fi


export LOCALCLASSPATH
cd $CLOCKCLIENT_HOME
/usr/bin/java -cp $LOCALCLASSPATH de.hmedia.clockmanager.client.ClockClientLauncher >> $LOGFILE 2>&1
